@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2016 sqlmap developers (http://sqlmap.org/)
-See the file 'doc/COPYING' for copying permission
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+See the file 'LICENSE' for copying permission
 """
 
 from lib.core.data import logger
@@ -19,35 +19,37 @@ def checkDependencies():
 
         try:
             if dbmsName in (DBMS.MSSQL, DBMS.SYBASE):
-                import _mssql
-                import pymssql
+                __import__("_mssql")
 
+                import pymssql
                 if not hasattr(pymssql, "__version__") or pymssql.__version__ < "1.0.2":
                     warnMsg = "'%s' third-party library must be " % data[1]
                     warnMsg += "version >= 1.0.2 to work properly. "
-                    warnMsg += "Download from %s" % data[2]
+                    warnMsg += "Download from '%s'" % data[2]
                     logger.warn(warnMsg)
             elif dbmsName == DBMS.MYSQL:
-                import pymysql
+                __import__("pymysql")
             elif dbmsName == DBMS.PGSQL:
-                import psycopg2
+                __import__("psycopg2")
             elif dbmsName == DBMS.ORACLE:
-                import cx_Oracle
+                __import__("cx_Oracle")
             elif dbmsName == DBMS.SQLITE:
-                import sqlite3
+                __import__("sqlite3")
             elif dbmsName == DBMS.ACCESS:
-                import pyodbc
+                __import__("pyodbc")
             elif dbmsName == DBMS.FIREBIRD:
-                import kinterbasdb
+                __import__("kinterbasdb")
             elif dbmsName == DBMS.DB2:
-                import ibm_db_dbi
+                __import__("ibm_db_dbi")
             elif dbmsName == DBMS.HSQLDB:
-                import jaydebeapi
-                import jpype
-        except ImportError:
+                __import__("jaydebeapi")
+                __import__("jpype")
+            elif dbmsName == DBMS.INFORMIX:
+                __import__("ibm_db_dbi")
+        except:
             warnMsg = "sqlmap requires '%s' third-party library " % data[1]
             warnMsg += "in order to directly connect to the DBMS "
-            warnMsg += "%s. Download from %s" % (dbmsName, data[2])
+            warnMsg += "'%s'. Download from '%s'" % (dbmsName, data[2])
             logger.warn(warnMsg)
             missing_libraries.add(data[1])
 
@@ -57,41 +59,41 @@ def checkDependencies():
         logger.debug(debugMsg)
 
     try:
-        import impacket
+        __import__("impacket")
         debugMsg = "'python-impacket' third-party library is found"
         logger.debug(debugMsg)
     except ImportError:
         warnMsg = "sqlmap requires 'python-impacket' third-party library for "
         warnMsg += "out-of-band takeover feature. Download from "
-        warnMsg += "http://code.google.com/p/impacket/"
+        warnMsg += "'http://code.google.com/p/impacket/'"
         logger.warn(warnMsg)
         missing_libraries.add('python-impacket')
 
     try:
-        import ntlm
+        __import__("ntlm")
         debugMsg = "'python-ntlm' third-party library is found"
         logger.debug(debugMsg)
     except ImportError:
         warnMsg = "sqlmap requires 'python-ntlm' third-party library "
         warnMsg += "if you plan to attack a web application behind NTLM "
-        warnMsg += "authentication. Download from http://code.google.com/p/python-ntlm/"
+        warnMsg += "authentication. Download from 'http://code.google.com/p/python-ntlm/'"
         logger.warn(warnMsg)
         missing_libraries.add('python-ntlm')
 
     try:
-        from websocket import ABNF
+        __import__("websocket.ABNF")
         debugMsg = "'python websocket-client' library is found"
         logger.debug(debugMsg)
     except ImportError:
         warnMsg = "sqlmap requires 'websocket-client' third-party library "
         warnMsg += "if you plan to attack a web application using WebSocket. "
-        warnMsg += "Download from https://pypi.python.org/pypi/websocket-client/"
+        warnMsg += "Download from 'https://pypi.python.org/pypi/websocket-client/'"
         logger.warn(warnMsg)
         missing_libraries.add('websocket-client')
 
     if IS_WIN:
         try:
-            import pyreadline
+            __import__("pyreadline")
             debugMsg = "'python-pyreadline' third-party library is found"
             logger.debug(debugMsg)
         except ImportError:
@@ -99,11 +101,10 @@ def checkDependencies():
             warnMsg += "be able to take advantage of the sqlmap TAB "
             warnMsg += "completion and history support features in the SQL "
             warnMsg += "shell and OS shell. Download from "
-            warnMsg += "http://ipython.scipy.org/moin/PyReadline/Intro"
+            warnMsg += "'http://ipython.scipy.org/moin/PyReadline/Intro'"
             logger.warn(warnMsg)
             missing_libraries.add('python-pyreadline')
 
     if len(missing_libraries) == 0:
         infoMsg = "all dependencies are installed"
         logger.info(infoMsg)
-
