@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2016 sqlmap developers (http://sqlmap.org/)
-See the file 'doc/COPYING' for copying permission
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+See the file 'LICENSE' for copying permission
 """
 
 try:
@@ -16,6 +16,9 @@ try:
 
     # problems on FreeBSD (Reference: http://www.eggheadcafe.com/microsoft/Python/35880259/multiprocessing-on-freebsd.aspx)
     _ = multiprocessing.Queue()
+
+    # problems with ctypes (Reference: https://github.com/sqlmapproject/sqlmap/issues/2952)
+    _ = multiprocessing.Value('i')
 except (ImportError, OSError):
     pass
 else:
@@ -25,6 +28,8 @@ else:
     except NotImplementedError:
         pass
 
+import base64
+import binascii
 import gc
 import os
 import re
@@ -35,6 +40,7 @@ import zipfile
 from hashlib import md5
 from hashlib import sha1
 from hashlib import sha224
+from hashlib import sha256
 from hashlib import sha384
 from hashlib import sha512
 from Queue import Queue
@@ -67,6 +73,7 @@ from lib.core.exception import SqlmapDataException
 from lib.core.exception import SqlmapUserQuitException
 from lib.core.settings import COMMON_PASSWORD_SUFFIXES
 from lib.core.settings import COMMON_USER_COLUMNS
+from lib.core.settings import DEV_EMAIL_ADDRESS
 from lib.core.settings import DUMMY_USER_PREFIX
 from lib.core.settings import HASH_MOD_ITEM_DISPLAY
 from lib.core.settings import HASH_RECOGNITION_QUIT_THRESHOLD
@@ -77,6 +84,7 @@ from lib.core.settings import UNICODE_ENCODING
 from lib.core.settings import ROTATING_CHARS
 from lib.core.wordlist import Wordlist
 from thirdparty.colorama.initialise import init as coloramainit
+from thirdparty.oset.pyoset import oset
 from thirdparty.pydes.pyDes import des
 from thirdparty.pydes.pyDes import CBC
 
@@ -127,7 +135,6 @@ def postgres_passwd(password, username, uppercase=False):
     'md599e5ea7a6f7c3269995cba3927fd0093'
     """
 
-
     if isinstance(username, unicode):
         username = unicode.encode(username, UNICODE_ENCODING)
 
@@ -149,7 +156,7 @@ def mssql_passwd(password, salt, uppercase=False):
     """
 
     binsalt = hexdecode(salt)
-    unistr = "".join(map(lambda c: ("%s\0" if ord(c) < 256 else "%s") % utf8encode(c), password))
+    unistr = "".join(("%s\0" if ord(_) < 256 else "%s") % utf8encode(_) for _ in password)
 
     retVal = "0100%s%s" % (salt, sha1(unistr + binsalt).hexdigest())
 
@@ -167,7 +174,7 @@ def mssql_old_passwd(password, salt, uppercase=True):  # prior to version '2005'
     """
 
     binsalt = hexdecode(salt)
-    unistr = "".join(map(lambda c: ("%s\0" if ord(c) < 256 else "%s") % utf8encode(c), password))
+    unistr = "".join(("%s\0" if ord(_) < 256 else "%s") % utf8encode(_) for _ in password)
 
     retVal = "0100%s%s%s" % (salt, sha1(unistr + binsalt).hexdigest(), sha1(unistr.upper() + binsalt).hexdigest())
 
@@ -183,7 +190,7 @@ def mssql_new_passwd(password, salt, uppercase=False):
     """
 
     binsalt = hexdecode(salt)
-    unistr = "".join(map(lambda c: ("%s\0" if ord(c) < 256 else "%s") % utf8encode(c), password))
+    unistr = "".join(("%s\0" if ord(_) < 256 else "%s") % utf8encode(_) for _ in password)
 
     retVal = "0200%s%s" % (salt, sha512(unistr + binsalt).hexdigest())
 
@@ -254,6 +261,38 @@ def sha1_generic_passwd(password, uppercase=False):
 
     return retVal.upper() if uppercase else retVal.lower()
 
+def apache_sha1_passwd(password, **kwargs):
+    """
+    >>> apache_sha1_passwd(password='testpass')
+    '{SHA}IGyAQTualsExLMNGt9JRe4RGPt0='
+    """
+
+    return "{SHA}%s" % base64.b64encode(sha1(password).digest())
+
+def ssha_passwd(password, salt, **kwargs):
+    """
+    >>> ssha_passwd(password='testpass', salt='salt')
+    '{SSHA}mU1HPTvnmoXOhE4ROHP6sWfbfoRzYWx0'
+    """
+
+    return "{SSHA}%s" % base64.b64encode(sha1(password + salt).digest() + salt)
+
+def ssha256_passwd(password, salt, **kwargs):
+    """
+    >>> ssha256_passwd(password='testpass', salt='salt')
+    '{SSHA256}hhubsLrO/Aje9F/kJrgv5ZLE40UmTrVWvI7Dt6InP99zYWx0'
+    """
+
+    return "{SSHA256}%s" % base64.b64encode(sha256(password + salt).digest() + salt)
+
+def ssha512_passwd(password, salt, **kwargs):
+    """
+    >>> ssha512_passwd(password='testpass', salt='salt')
+    '{SSHA512}mCUSLfPMhXCQOJl9WHW/QMn9v9sjq7Ht/Wk7iVau8vLOfh+PeynkGMikqIE8sStFd0khdfcCD8xZmC6UyjTxsHNhbHQ='
+    """
+
+    return "{SSHA512}%s" % base64.b64encode(sha512(password + salt).digest() + salt)
+
 def sha224_generic_passwd(password, uppercase=False):
     """
     >>> sha224_generic_passwd(password='testpass', uppercase=False)
@@ -264,6 +303,16 @@ def sha224_generic_passwd(password, uppercase=False):
 
     return retVal.upper() if uppercase else retVal.lower()
 
+def sha256_generic_passwd(password, uppercase=False):
+    """
+    >>> sha256_generic_passwd(password='testpass', uppercase=False)
+    '13d249f2cb4127b40cfa757866850278793f814ded3c587fe5889e889a7a9f6c'
+    """
+
+    retVal = sha256(password).hexdigest()
+
+    return retVal.upper() if uppercase else retVal.lower()
+
 def sha384_generic_passwd(password, uppercase=False):
     """
     >>> sha384_generic_passwd(password='testpass', uppercase=False)
@@ -284,7 +333,7 @@ def sha512_generic_passwd(password, uppercase=False):
 
     return retVal.upper() if uppercase else retVal.lower()
 
-def crypt_generic_passwd(password, salt, uppercase=False):
+def crypt_generic_passwd(password, salt, **kwargs):
     """
     Reference(s):
         http://docs.python.org/library/crypt.html
@@ -296,17 +345,133 @@ def crypt_generic_passwd(password, salt, uppercase=False):
     'rl.3StKT.4T8M'
     """
 
-    retVal = crypt(password, salt)
+    return crypt(password, salt)
 
-    return retVal.upper() if uppercase else retVal
+def unix_md5_passwd(password, salt, magic="$1$", **kwargs):
+    """
+    Reference(s):
+        http://www.sabren.net/code/python/crypt/md5crypt.py
 
-def wordpress_passwd(password, salt, count, prefix, uppercase=False):
+    >>> unix_md5_passwd(password='testpass', salt='aD9ZLmkp')
+    '$1$aD9ZLmkp$DRM5a7rRZGyuuOPOjTEk61'
+    """
+
+    def _encode64(value, count):
+        output = ""
+
+        while (count - 1 >= 0):
+            count = count - 1
+            output += ITOA64[value & 0x3f]
+            value = value >> 6
+
+        return output
+
+    if isinstance(password, unicode):
+        password = password.encode(UNICODE_ENCODING)
+
+    if isinstance(magic, unicode):
+        magic = magic.encode(UNICODE_ENCODING)
+
+    if isinstance(salt, unicode):
+        salt = salt.encode(UNICODE_ENCODING)
+
+    salt = salt[:8]
+    ctx = password + magic + salt
+    final = md5(password + salt + password).digest()
+
+    for pl in xrange(len(password), 0, -16):
+        if pl > 16:
+            ctx = ctx + final[:16]
+        else:
+            ctx = ctx + final[:pl]
+
+    i = len(password)
+    while i:
+        if i & 1:
+            ctx = ctx + chr(0)  # if ($i & 1) { $ctx->add(pack("C", 0)); }
+        else:
+            ctx = ctx + password[0]
+        i = i >> 1
+
+    final = md5(ctx).digest()
+
+    for i in xrange(1000):
+        ctx1 = ""
+
+        if i & 1:
+            ctx1 = ctx1 + password
+        else:
+            ctx1 = ctx1 + final[:16]
+
+        if i % 3:
+            ctx1 = ctx1 + salt
+
+        if i % 7:
+            ctx1 = ctx1 + password
+
+        if i & 1:
+            ctx1 = ctx1 + final[:16]
+        else:
+            ctx1 = ctx1 + password
+
+        final = md5(ctx1).digest()
+
+    hash_ = _encode64((int(ord(final[0])) << 16) | (int(ord(final[6])) << 8) | (int(ord(final[12]))), 4)
+    hash_ = hash_ + _encode64((int(ord(final[1])) << 16) | (int(ord(final[7])) << 8) | (int(ord(final[13]))), 4)
+    hash_ = hash_ + _encode64((int(ord(final[2])) << 16) | (int(ord(final[8])) << 8) | (int(ord(final[14]))), 4)
+    hash_ = hash_ + _encode64((int(ord(final[3])) << 16) | (int(ord(final[9])) << 8) | (int(ord(final[15]))), 4)
+    hash_ = hash_ + _encode64((int(ord(final[4])) << 16) | (int(ord(final[10])) << 8) | (int(ord(final[5]))), 4)
+    hash_ = hash_ + _encode64((int(ord(final[11]))), 2)
+
+    return "%s%s$%s" % (magic, salt, hash_)
+
+def joomla_passwd(password, salt, **kwargs):
+    """
+    Reference: https://stackoverflow.com/a/10428239
+
+    >>> joomla_passwd(password='testpass', salt='6GGlnaquVXI80b3HRmSyE3K1wEFFaBIf')
+    'e3d5794da74e917637332e0d21b76328:6GGlnaquVXI80b3HRmSyE3K1wEFFaBIf'
+    """
+
+    return "%s:%s" % (md5("%s%s" % (password, salt)).hexdigest(), salt)
+
+def django_md5_passwd(password, salt, **kwargs):
+    """
+    Reference: https://github.com/jay0lee/GAM/blob/master/src/passlib/handlers/django.py
+
+    >>> django_md5_passwd(password='testpass', salt='salt')
+    'md5$salt$972141bcbcb6a0acc96e92309175b3c5'
+    """
+
+    return "md5$%s$%s" % (salt, md5("%s%s" % (salt, password)).hexdigest())
+
+def django_sha1_passwd(password, salt, **kwargs):
+    """
+    Reference: https://github.com/jay0lee/GAM/blob/master/src/passlib/handlers/django.py
+
+    >>> django_sha1_passwd(password='testpass', salt='salt')
+    'sha1$salt$6ce0e522aba69d8baa873f01420fccd0250fc5b2'
+    """
+
+    return "sha1$%s$%s" % (salt, sha1("%s%s" % (salt, password)).hexdigest())
+
+def vbulletin_passwd(password, salt, **kwargs):
+    """
+    Reference: https://stackoverflow.com/a/2202810
+
+    >>> vbulletin_passwd(password='testpass', salt='salt')
+    '85c4d8ea77ebef2236fb7e9d24ba9482:salt'
+    """
+
+    return "%s:%s" % (md5("%s%s" % (md5(password).hexdigest(), salt)).hexdigest(), salt)
+
+def wordpress_passwd(password, salt, count, prefix, **kwargs):
     """
     Reference(s):
         http://packetstormsecurity.org/files/74448/phpassbrute.py.txt
         http://scriptserver.mainframe8.com/wordpress_password_hasher.php
 
-    >>> wordpress_passwd(password='testpass', salt='aD9ZLmkp', count=2048, prefix='$P$9aD9ZLmkp', uppercase=False)
+    >>> wordpress_passwd(password='testpass', salt='aD9ZLmkp', count=2048, prefix='$P$9aD9ZLmkp')
     '$P$9aD9ZLmkpsN4A83G8MefaaP888gVKX0'
     """
 
@@ -353,63 +518,77 @@ def wordpress_passwd(password, salt, count, prefix, uppercase=False):
         _.update(password)
         hash_ = _.digest()
 
-    retVal = prefix + _encode64(hash_, 16)
-
-    return retVal.upper() if uppercase else retVal
+    return "%s%s" % (prefix, _encode64(hash_, 16))
 
 __functions__ = {
-                    HASH.MYSQL: mysql_passwd,
-                    HASH.MYSQL_OLD: mysql_old_passwd,
-                    HASH.POSTGRES: postgres_passwd,
-                    HASH.MSSQL: mssql_passwd,
-                    HASH.MSSQL_OLD: mssql_old_passwd,
-                    HASH.MSSQL_NEW: mssql_new_passwd,
-                    HASH.ORACLE: oracle_passwd,
-                    HASH.ORACLE_OLD: oracle_old_passwd,
-                    HASH.MD5_GENERIC: md5_generic_passwd,
-                    HASH.SHA1_GENERIC: sha1_generic_passwd,
-                    HASH.SHA224_GENERIC: sha224_generic_passwd,
-                    HASH.SHA384_GENERIC: sha384_generic_passwd,
-                    HASH.SHA512_GENERIC: sha512_generic_passwd,
-                    HASH.CRYPT_GENERIC: crypt_generic_passwd,
-                    HASH.WORDPRESS: wordpress_passwd,
-                }
+    HASH.MYSQL: mysql_passwd,
+    HASH.MYSQL_OLD: mysql_old_passwd,
+    HASH.POSTGRES: postgres_passwd,
+    HASH.MSSQL: mssql_passwd,
+    HASH.MSSQL_OLD: mssql_old_passwd,
+    HASH.MSSQL_NEW: mssql_new_passwd,
+    HASH.ORACLE: oracle_passwd,
+    HASH.ORACLE_OLD: oracle_old_passwd,
+    HASH.MD5_GENERIC: md5_generic_passwd,
+    HASH.SHA1_GENERIC: sha1_generic_passwd,
+    HASH.SHA224_GENERIC: sha224_generic_passwd,
+    HASH.SHA256_GENERIC: sha256_generic_passwd,
+    HASH.SHA384_GENERIC: sha384_generic_passwd,
+    HASH.SHA512_GENERIC: sha512_generic_passwd,
+    HASH.CRYPT_GENERIC: crypt_generic_passwd,
+    HASH.JOOMLA: joomla_passwd,
+    HASH.DJANGO_MD5: django_md5_passwd,
+    HASH.DJANGO_SHA1: django_sha1_passwd,
+    HASH.WORDPRESS: wordpress_passwd,
+    HASH.APACHE_MD5_CRYPT: unix_md5_passwd,
+    HASH.UNIX_MD5_CRYPT: unix_md5_passwd,
+    HASH.APACHE_SHA1: apache_sha1_passwd,
+    HASH.VBULLETIN: vbulletin_passwd,
+    HASH.VBULLETIN_OLD: vbulletin_passwd,
+    HASH.SSHA: ssha_passwd,
+    HASH.SSHA256: ssha256_passwd,
+    HASH.SSHA512: ssha512_passwd,
+    HASH.MD5_BASE64: md5_generic_passwd,
+    HASH.SHA1_BASE64: sha1_generic_passwd,
+    HASH.SHA256_BASE64: sha256_generic_passwd,
+    HASH.SHA512_BASE64: sha512_generic_passwd,
+}
 
 def storeHashesToFile(attack_dict):
     if not attack_dict:
         return
 
+    items = oset()
+
+    for user, hashes in attack_dict.items():
+        for hash_ in hashes:
+            hash_ = hash_.split()[0] if hash_ and hash_.strip() else hash_
+            if hash_ and hash_ != NULL and hashRecognition(hash_):
+                item = None
+                if user and not user.startswith(DUMMY_USER_PREFIX):
+                    item = "%s:%s\n" % (user.encode(UNICODE_ENCODING), hash_.encode(UNICODE_ENCODING))
+                else:
+                    item = "%s\n" % hash_.encode(UNICODE_ENCODING)
+
+                if item and item not in items:
+                    items.add(item)
+
     if kb.storeHashesChoice is None:
         message = "do you want to store hashes to a temporary file "
         message += "for eventual further processing with other tools [y/N] "
-        test = readInput(message, default="N")
-        kb.storeHashesChoice = test[0] in ("y", "Y")
 
-    if not kb.storeHashesChoice:
-        return
+        kb.storeHashesChoice = readInput(message, default='N', boolean=True)
 
-    handle, filename = tempfile.mkstemp(prefix=MKSTEMP_PREFIX.HASHES, suffix=".txt")
-    os.close(handle)
+    if items and kb.storeHashesChoice:
+        handle, filename = tempfile.mkstemp(prefix=MKSTEMP_PREFIX.HASHES, suffix=".txt")
+        os.close(handle)
 
-    infoMsg = "writing hashes to a temporary file '%s' " % filename
-    logger.info(infoMsg)
+        infoMsg = "writing hashes to a temporary file '%s' " % filename
+        logger.info(infoMsg)
 
-    items = set()
-
-    with open(filename, "w+") as f:
-        for user, hashes in attack_dict.items():
-            for hash_ in hashes:
-                hash_ = hash_.split()[0] if hash_ and hash_.strip() else hash_
-                if hash_ and hash_ != NULL and hashRecognition(hash_):
-                    item = None
-                    if user and not user.startswith(DUMMY_USER_PREFIX):
-                        item = "%s:%s\n" % (user.encode(UNICODE_ENCODING), hash_.encode(UNICODE_ENCODING))
-                    else:
-                        item = "%s\n" % hash_.encode(UNICODE_ENCODING)
-
-                    if item and item not in items:
-                        f.write(item)
-                        items.add(item)
+        with open(filename, "w+") as f:
+            for item in items:
+                f.write(item)
 
 def attackCachedUsersPasswords():
     if kb.data.cachedUsersPasswords:
@@ -435,8 +614,8 @@ def attackDumpedTable():
         if not count:
             return
 
-        infoMsg = "analyzing table dump for possible password hashes"
-        logger.info(infoMsg)
+        debugMsg = "analyzing table dump for possible password hashes"
+        logger.debug(debugMsg)
 
         found = False
         col_user = ''
@@ -453,24 +632,24 @@ def attackDumpedTable():
                 break
 
             for column in columns:
-                if column == col_user or column == '__infos__':
+                if column == col_user or column == "__infos__":
                     continue
 
-                if len(table[column]['values']) <= i:
+                if len(table[column]["values"]) <= i:
                     continue
 
-                value = table[column]['values'][i]
+                value = table[column]["values"][i]
 
                 if hashRecognition(value):
                     found = True
 
-                    if col_user and i < len(table[col_user]['values']):
-                        if table[col_user]['values'][i] not in attack_dict:
-                            attack_dict[table[col_user]['values'][i]] = []
+                    if col_user and i < len(table[col_user]["values"]):
+                        if table[col_user]["values"][i] not in attack_dict:
+                            attack_dict[table[col_user]["values"][i]] = []
 
-                        attack_dict[table[col_user]['values'][i]].append(value)
+                        attack_dict[table[col_user]["values"][i]].append(value)
                     else:
-                        attack_dict['%s%d' % (DUMMY_USER_PREFIX, i)] = [value]
+                        attack_dict["%s%d" % (DUMMY_USER_PREFIX, i)] = [value]
 
                     col_passwords.add(column)
 
@@ -482,11 +661,11 @@ def attackDumpedTable():
             storeHashesToFile(attack_dict)
 
             message = "do you want to crack them via a dictionary-based attack? %s" % ("[y/N/q]" if conf.multipleTargets else "[Y/n/q]")
-            test = readInput(message, default="N" if conf.multipleTargets else "Y")
+            choice = readInput(message, default='N' if conf.multipleTargets else 'Y').upper()
 
-            if test[0] in ("n", "N"):
+            if choice == 'N':
                 return
-            elif test[0] in ("q", "Q"):
+            elif choice == 'Q':
                 raise SqlmapUserQuitException
 
             results = dictionaryAttack(attack_dict)
@@ -496,8 +675,8 @@ def attackDumpedTable():
                 if hash_:
                     lut[hash_.lower()] = password
 
-            infoMsg = "postprocessing table dump"
-            logger.info(infoMsg)
+            debugMsg = "post-processing table dump"
+            logger.debug(debugMsg)
 
             for i in xrange(count):
                 for column in columns:
@@ -516,9 +695,7 @@ def hashRecognition(value):
     if isinstance(value, basestring):
         for name, regex in getPublicTypeMembers(HASH):
             # Hashes for Oracle and old MySQL look the same hence these checks
-            if isOracle and regex == HASH.MYSQL_OLD:
-                continue
-            elif isMySQL and regex == HASH.ORACLE_OLD:
+            if isOracle and regex == HASH.MYSQL_OLD or isMySQL and regex == HASH.ORACLE_OLD:
                 continue
             elif regex == HASH.CRYPT_GENERIC:
                 if any((value.lower() == value, value.upper() == value)):
@@ -529,13 +706,13 @@ def hashRecognition(value):
 
     return retVal
 
-def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc_count, wordlists, custom_wordlist):
+def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc_count, wordlists, custom_wordlist, api):
     if IS_WIN:
         coloramainit()
 
     count = 0
     rotator = 0
-    hashes = set([item[0][1] for item in attack_info])
+    hashes = set(item[0][1] for item in attack_info)
 
     wordlist = Wordlist(wordlists, proc_id, getattr(proc_count, "value", 0), custom_wordlist)
 
@@ -544,6 +721,8 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
             if not attack_info:
                 break
 
+            count += 1
+
             if not isinstance(word, basestring):
                 continue
 
@@ -553,8 +732,6 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
             try:
                 current = __functions__[hash_regex](password=word, uppercase=False)
 
-                count += 1
-
                 if current in hashes:
                     for item in attack_info[:]:
                         ((user, hash_), _) = item
@@ -581,9 +758,9 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
                     if rotator >= len(ROTATING_CHARS):
                         rotator = 0
 
-                    status = 'current status: %s... %s' % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
+                    status = "current status: %s... %s" % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
 
-                    if not hasattr(conf, "api"):
+                    if not api:
                         dataToStdout("\r[%s] [INFO] %s" % (time.strftime("%X"), status))
 
             except KeyboardInterrupt:
@@ -594,7 +771,7 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
 
             except Exception, e:
                 warnMsg = "there was a problem while hashing entry: %s (%s). " % (repr(word), e)
-                warnMsg += "Please report by e-mail to 'dev@sqlmap.org'"
+                warnMsg += "Please report by e-mail to '%s'" % DEV_EMAIL_ADDRESS
                 logger.critical(warnMsg)
 
     except KeyboardInterrupt:
@@ -605,7 +782,7 @@ def _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, proc_id, proc
             with proc_count.get_lock():
                 proc_count.value -= 1
 
-def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found, proc_id, proc_count, wordlists, custom_wordlist):
+def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found, proc_id, proc_count, wordlists, custom_wordlist, api):
     if IS_WIN:
         coloramainit()
 
@@ -619,7 +796,6 @@ def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found
             if found.value:
                 break
 
-            current = __functions__[hash_regex](password=word, uppercase=False, **kwargs)
             count += 1
 
             if not isinstance(word, basestring):
@@ -629,6 +805,8 @@ def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found
                 word = word + suffix
 
             try:
+                current = __functions__[hash_regex](password=word, uppercase=False, **kwargs)
+
                 if hash_ == current:
                     if hash_regex == HASH.ORACLE_OLD:  # only for cosmetic purposes
                         word = word.upper()
@@ -650,14 +828,16 @@ def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found
 
                 elif (proc_id == 0 or getattr(proc_count, "value", 0) == 1) and count % HASH_MOD_ITEM_DISPLAY == 0:
                     rotator += 1
+
                     if rotator >= len(ROTATING_CHARS):
                         rotator = 0
-                    status = 'current status: %s... %s' % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
+
+                    status = "current status: %s... %s" % (word.ljust(5)[:5], ROTATING_CHARS[rotator])
 
                     if user and not user.startswith(DUMMY_USER_PREFIX):
-                        status += ' (user: %s)' % user
+                        status += " (user: %s)" % user
 
-                    if not hasattr(conf, "api"):
+                    if not api:
                         dataToStdout("\r[%s] [INFO] %s" % (time.strftime("%X"), status))
 
             except KeyboardInterrupt:
@@ -668,7 +848,7 @@ def _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found
 
             except Exception, e:
                 warnMsg = "there was a problem while hashing entry: %s (%s). " % (repr(word), e)
-                warnMsg += "Please report by e-mail to 'dev@sqlmap.org'"
+                warnMsg += "Please report by e-mail to '%s'" % DEV_EMAIL_ADDRESS
                 logger.critical(warnMsg)
 
     except KeyboardInterrupt:
@@ -715,40 +895,58 @@ def dictionaryAttack(attack_dict):
                 hash_ = hash_.split()[0] if hash_ and hash_.strip() else hash_
 
                 if re.match(hash_regex, hash_):
-                    item = None
+                    try:
+                        item = None
 
-                    if hash_regex not in (HASH.CRYPT_GENERIC, HASH.WORDPRESS):
-                        hash_ = hash_.lower()
+                        if hash_regex not in (HASH.CRYPT_GENERIC, HASH.JOOMLA, HASH.WORDPRESS, HASH.UNIX_MD5_CRYPT, HASH.APACHE_MD5_CRYPT, HASH.APACHE_SHA1, HASH.VBULLETIN, HASH.VBULLETIN_OLD, HASH.SSHA, HASH.SSHA256, HASH.SSHA512, HASH.DJANGO_MD5, HASH.DJANGO_SHA1, HASH.MD5_BASE64, HASH.SHA1_BASE64, HASH.SHA256_BASE64, HASH.SHA512_BASE64):
+                            hash_ = hash_.lower()
 
-                    if hash_regex in (HASH.MYSQL, HASH.MYSQL_OLD, HASH.MD5_GENERIC, HASH.SHA1_GENERIC):
-                        item = [(user, hash_), {}]
-                    elif hash_regex in (HASH.ORACLE_OLD, HASH.POSTGRES):
-                        item = [(user, hash_), {'username': user}]
-                    elif hash_regex in (HASH.ORACLE,):
-                        item = [(user, hash_), {'salt': hash_[-20:]}]
-                    elif hash_regex in (HASH.MSSQL, HASH.MSSQL_OLD, HASH.MSSQL_NEW):
-                        item = [(user, hash_), {'salt': hash_[6:14]}]
-                    elif hash_regex in (HASH.CRYPT_GENERIC,):
-                        item = [(user, hash_), {'salt': hash_[0:2]}]
-                    elif hash_regex in (HASH.WORDPRESS,):
-                        if ITOA64.index(hash_[3]) < 32:
-                            item = [(user, hash_), {'salt': hash_[4:12], 'count': 1 << ITOA64.index(hash_[3]), 'prefix': hash_[:12]}]
-                        else:
-                            warnMsg = "invalid hash '%s'" % hash_
-                            logger.warn(warnMsg)
+                        if hash_regex in (HASH.MD5_BASE64, HASH.SHA1_BASE64, HASH.SHA256_BASE64, HASH.SHA512_BASE64):
+                            item = [(user, hash_.decode("base64").encode("hex")), {}]
+                        elif hash_regex in (HASH.MYSQL, HASH.MYSQL_OLD, HASH.MD5_GENERIC, HASH.SHA1_GENERIC, HASH.APACHE_SHA1):
+                            item = [(user, hash_), {}]
+                        elif hash_regex in (HASH.SSHA,):
+                            item = [(user, hash_), {"salt": hash_.decode("base64")[20:]}]
+                        elif hash_regex in (HASH.SSHA256,):
+                            item = [(user, hash_), {"salt": hash_.decode("base64")[32:]}]
+                        elif hash_regex in (HASH.SSHA512,):
+                            item = [(user, hash_), {"salt": hash_.decode("base64")[64:]}]
+                        elif hash_regex in (HASH.ORACLE_OLD, HASH.POSTGRES):
+                            item = [(user, hash_), {'username': user}]
+                        elif hash_regex in (HASH.ORACLE,):
+                            item = [(user, hash_), {"salt": hash_[-20:]}]
+                        elif hash_regex in (HASH.MSSQL, HASH.MSSQL_OLD, HASH.MSSQL_NEW):
+                            item = [(user, hash_), {"salt": hash_[6:14]}]
+                        elif hash_regex in (HASH.CRYPT_GENERIC,):
+                            item = [(user, hash_), {"salt": hash_[0:2]}]
+                        elif hash_regex in (HASH.UNIX_MD5_CRYPT, HASH.APACHE_MD5_CRYPT):
+                            item = [(user, hash_), {"salt": hash_.split('$')[2], "magic": "$%s$" % hash_.split('$')[1]}]
+                        elif hash_regex in (HASH.JOOMLA, HASH.VBULLETIN, HASH.VBULLETIN_OLD):
+                            item = [(user, hash_), {"salt": hash_.split(':')[-1]}]
+                        elif hash_regex in (HASH.DJANGO_MD5, HASH.DJANGO_SHA1):
+                            item = [(user, hash_), {"salt": hash_.split('$')[1]}]
+                        elif hash_regex in (HASH.WORDPRESS,):
+                            if ITOA64.index(hash_[3]) < 32:
+                                item = [(user, hash_), {"salt": hash_[4:12], "count": 1 << ITOA64.index(hash_[3]), "prefix": hash_[:12]}]
+                            else:
+                                warnMsg = "invalid hash '%s'" % hash_
+                                logger.warn(warnMsg)
 
-                    if item and hash_ not in keys:
-                        resumed = hashDBRetrieve(hash_)
-                        if not resumed:
-                            attack_info.append(item)
-                            user_hash.append(item[0])
-                        else:
-                            infoMsg = "resuming password '%s' for hash '%s'" % (resumed, hash_)
-                            if user and not user.startswith(DUMMY_USER_PREFIX):
-                                infoMsg += " for user '%s'" % user
-                            logger.info(infoMsg)
-                            resumes.append((user, hash_, resumed))
-                        keys.add(hash_)
+                        if item and hash_ not in keys:
+                            resumed = hashDBRetrieve(hash_)
+                            if not resumed:
+                                attack_info.append(item)
+                                user_hash.append(item[0])
+                            else:
+                                infoMsg = "resuming password '%s' for hash '%s'" % (resumed, hash_)
+                                if user and not user.startswith(DUMMY_USER_PREFIX):
+                                    infoMsg += " for user '%s'" % user
+                                logger.info(infoMsg)
+                                resumes.append((user, hash_, resumed))
+                            keys.add(hash_)
+
+                    except (binascii.Error, IndexError):
+                        pass
 
         if not attack_info:
             continue
@@ -757,7 +955,7 @@ def dictionaryAttack(attack_dict):
             while not kb.wordlists:
 
                 # the slowest of all methods hence smaller default dict
-                if hash_regex in (HASH.ORACLE_OLD, HASH.WORDPRESS):
+                if hash_regex in (HASH.ORACLE_OLD,):
                     dictPaths = [paths.SMALL_DICT]
                 else:
                     dictPaths = [paths.WORDLIST]
@@ -766,20 +964,20 @@ def dictionaryAttack(attack_dict):
                 message += "[1] default dictionary file '%s' (press Enter)\n" % dictPaths[0]
                 message += "[2] custom dictionary file\n"
                 message += "[3] file with list of dictionary files"
-                choice = readInput(message, default="1")
+                choice = readInput(message, default='1')
 
                 try:
-                    if choice == "2":
+                    if choice == '2':
                         message = "what's the custom dictionary's location?\n"
-                        dictPaths = [readInput(message)]
-
-                        logger.info("using custom dictionary")
-                    elif choice == "3":
+                        dictPath = readInput(message)
+                        if dictPath:
+                            dictPaths = [dictPath]
+                            logger.info("using custom dictionary")
+                    elif choice == '3':
                         message = "what's the list file location?\n"
                         listPath = readInput(message)
                         checkFile(listPath)
                         dictPaths = getFileItems(listPath)
-
                         logger.info("using custom list of dictionaries")
                     else:
                         logger.info("using default dictionary")
@@ -805,9 +1003,8 @@ def dictionaryAttack(attack_dict):
                     logger.critical(warnMsg)
 
             message = "do you want to use common password suffixes? (slow!) [y/N] "
-            test = readInput(message, default="N")
 
-            if test[0] in ("y", "Y"):
+            if readInput(message, default='N', boolean=True):
                 suffix_list += COMMON_PASSWORD_SUFFIXES
 
         infoMsg = "starting dictionary-based cracking (%s)" % __functions__[hash_regex].func_name
@@ -818,7 +1015,8 @@ def dictionaryAttack(attack_dict):
             if user and not user.startswith(DUMMY_USER_PREFIX):
                 custom_wordlist.append(normalizeUnicode(user))
 
-        if hash_regex in (HASH.MYSQL, HASH.MYSQL_OLD, HASH.MD5_GENERIC, HASH.SHA1_GENERIC):
+        # Algorithms without extra arguments (e.g. salt and/or username)
+        if hash_regex in (HASH.MYSQL, HASH.MYSQL_OLD, HASH.MD5_GENERIC, HASH.SHA1_GENERIC, HASH.SHA224_GENERIC, HASH.SHA256_GENERIC, HASH.SHA384_GENERIC, HASH.SHA512_GENERIC, HASH.APACHE_SHA1, HASH.VBULLETIN, HASH.VBULLETIN_OLD):
             for suffix in suffix_list:
                 if not attack_info or processException:
                     break
@@ -843,12 +1041,12 @@ def dictionaryAttack(attack_dict):
                         count = _multiprocessing.Value('i', _multiprocessing.cpu_count())
 
                         for i in xrange(_multiprocessing.cpu_count()):
-                            p = _multiprocessing.Process(target=_bruteProcessVariantA, args=(attack_info, hash_regex, suffix, retVal, i, count, kb.wordlists, custom_wordlist))
-                            processes.append(p)
+                            process = _multiprocessing.Process(target=_bruteProcessVariantA, args=(attack_info, hash_regex, suffix, retVal, i, count, kb.wordlists, custom_wordlist, conf.api))
+                            processes.append(process)
 
-                        for p in processes:
-                            p.daemon = True
-                            p.start()
+                        for process in processes:
+                            process.daemon = True
+                            process.start()
 
                         while count.value > 0:
                             time.sleep(0.5)
@@ -859,7 +1057,7 @@ def dictionaryAttack(attack_dict):
                         singleTimeWarnMessage(warnMsg)
 
                         retVal = Queue()
-                        _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, 0, 1, kb.wordlists, custom_wordlist)
+                        _bruteProcessVariantA(attack_info, hash_regex, suffix, retVal, 0, 1, kb.wordlists, custom_wordlist, conf.api)
 
                 except KeyboardInterrupt:
                     print
@@ -927,12 +1125,12 @@ def dictionaryAttack(attack_dict):
                             count = _multiprocessing.Value('i', _multiprocessing.cpu_count())
 
                             for i in xrange(_multiprocessing.cpu_count()):
-                                p = _multiprocessing.Process(target=_bruteProcessVariantB, args=(user, hash_, kwargs, hash_regex, suffix, retVal, found_, i, count, kb.wordlists, custom_wordlist))
-                                processes.append(p)
+                                process = _multiprocessing.Process(target=_bruteProcessVariantB, args=(user, hash_, kwargs, hash_regex, suffix, retVal, found_, i, count, kb.wordlists, custom_wordlist, conf.api))
+                                processes.append(process)
 
-                            for p in processes:
-                                p.daemon = True
-                                p.start()
+                            for process in processes:
+                                process.daemon = True
+                                process.start()
 
                             while count.value > 0:
                                 time.sleep(0.5)
@@ -951,7 +1149,7 @@ def dictionaryAttack(attack_dict):
                             found_ = Value()
                             found_.value = False
 
-                            _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found_, 0, 1, kb.wordlists, custom_wordlist)
+                            _bruteProcessVariantB(user, hash_, kwargs, hash_regex, suffix, retVal, found_, 0, 1, kb.wordlists, custom_wordlist, conf.api)
 
                             found = found_.value
 
