@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2016 sqlmap developers (http://sqlmap.org/)
-See the file 'doc/COPYING' for copying permission
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+See the file 'LICENSE' for copying permission
 """
 
 import re
@@ -27,10 +27,11 @@ from lib.core.data import conf
 from lib.core.data import kb
 from lib.core.data import logger
 from lib.core.data import queries
+from lib.core.dicts import DB2_PRIVS
+from lib.core.dicts import FIREBIRD_PRIVS
+from lib.core.dicts import INFORMIX_PRIVS
 from lib.core.dicts import MYSQL_PRIVS
 from lib.core.dicts import PGSQL_PRIVS
-from lib.core.dicts import FIREBIRD_PRIVS
-from lib.core.dicts import DB2_PRIVS
 from lib.core.enums import CHARSET_TYPE
 from lib.core.enums import DBMS
 from lib.core.enums import EXPECTED
@@ -160,11 +161,11 @@ class Users:
             conf.user = conf.user.upper()
 
         if conf.user:
-            users = conf.user.split(",")
+            users = conf.user.split(',')
 
             if Backend.isDbms(DBMS.MYSQL):
                 for user in users:
-                    parsedUser = re.search("[\047]*(.*?)[\047]*\@", user)
+                    parsedUser = re.search(r"['\"]?(.*?)['\"]?\@", user)
 
                     if parsedUser:
                         users[users.index(user)] = parsedUser.groups()[0]
@@ -219,7 +220,7 @@ class Users:
 
                 if Backend.isDbms(DBMS.MYSQL):
                     for user in users:
-                        parsedUser = re.search("[\047]*(.*?)[\047]*\@", user)
+                        parsedUser = re.search(r"['\"]?(.*?)['\"]?\@", user)
 
                         if parsedUser:
                             users[users.index(user)] = parsedUser.groups()[0]
@@ -234,7 +235,7 @@ class Users:
 
                 if retVal:
                     for user, password in filterPairValues(zip(retVal[0]["%s.name" % randStr], retVal[0]["%s.password" % randStr])):
-                        password = "0x%s" % hexencode(password).upper()
+                        password = "0x%s" % hexencode(password, conf.encoding).upper()
 
                         if user not in kb.data.cachedUsersPasswords:
                             kb.data.cachedUsersPasswords[user] = [password]
@@ -251,22 +252,25 @@ class Users:
                     if user in retrievedUsers:
                         continue
 
-                    infoMsg = "fetching number of password hashes "
-                    infoMsg += "for user '%s'" % user
-                    logger.info(infoMsg)
-
-                    if Backend.isDbms(DBMS.MSSQL) and Backend.isVersionWithin(("2005", "2008")):
-                        query = rootQuery.blind.count2 % user
+                    if Backend.isDbms(DBMS.INFORMIX):
+                        count = 1
                     else:
-                        query = rootQuery.blind.count % user
+                        infoMsg = "fetching number of password hashes "
+                        infoMsg += "for user '%s'" % user
+                        logger.info(infoMsg)
 
-                    count = inject.getValue(query, union=False, error=False, expected=EXPECTED.INT, charsetType=CHARSET_TYPE.DIGITS)
+                        if Backend.isDbms(DBMS.MSSQL) and Backend.isVersionWithin(("2005", "2008")):
+                            query = rootQuery.blind.count2 % user
+                        else:
+                            query = rootQuery.blind.count % user
 
-                    if not isNumPosStrValue(count):
-                        warnMsg = "unable to retrieve the number of password "
-                        warnMsg += "hashes for user '%s'" % user
-                        logger.warn(warnMsg)
-                        continue
+                        count = inject.getValue(query, union=False, error=False, expected=EXPECTED.INT, charsetType=CHARSET_TYPE.DIGITS)
+
+                        if not isNumPosStrValue(count):
+                            warnMsg = "unable to retrieve the number of password "
+                            warnMsg += "hashes for user '%s'" % user
+                            logger.warn(warnMsg)
+                            continue
 
                     infoMsg = "fetching password hashes for user '%s'" % user
                     logger.info(infoMsg)
@@ -282,11 +286,14 @@ class Users:
                                 query = rootQuery.blind.query2 % (user, index, user)
                             else:
                                 query = rootQuery.blind.query % (user, index, user)
+                        elif Backend.isDbms(DBMS.INFORMIX):
+                            query = rootQuery.blind.query % (user,)
                         else:
                             query = rootQuery.blind.query % (user, index)
 
                         password = unArrayizeValue(inject.getValue(query, union=False, error=False))
                         password = parsePasswordHash(password)
+
                         passwords.append(password)
 
                     if passwords:
@@ -300,9 +307,9 @@ class Users:
 
         if not kb.data.cachedUsersPasswords:
             errMsg = "unable to retrieve the password hashes for the "
-            errMsg += "database users (probably because the session "
-            errMsg += "user has no read privileges over the relevant "
-            errMsg += "system database table)"
+            errMsg += "database users (probably because the DBMS "
+            errMsg += "current user has no read privileges over the relevant "
+            errMsg += "system database table(s))"
             logger.error(errMsg)
         else:
             for user in kb.data.cachedUsersPasswords:
@@ -312,11 +319,11 @@ class Users:
 
             message = "do you want to perform a dictionary-based attack "
             message += "against retrieved password hashes? [Y/n/q]"
-            test = readInput(message, default="Y")
+            choice = readInput(message, default='Y').upper()
 
-            if test[0] in ("n", "N"):
+            if choice == 'N':
                 pass
-            elif test[0] in ("q", "Q"):
+            elif choice == 'Q':
                 raise SqlmapUserQuitException
             else:
                 attackCachedUsersPasswords()
@@ -338,11 +345,11 @@ class Users:
             conf.user = conf.user.upper()
 
         if conf.user:
-            users = conf.user.split(",")
+            users = conf.user.split(',')
 
             if Backend.isDbms(DBMS.MYSQL):
                 for user in users:
-                    parsedUser = re.search("[\047]*(.*?)[\047]*\@", user)
+                    parsedUser = re.search(r"['\"]?(.*?)['\"]?\@", user)
 
                     if parsedUser:
                         users[users.index(user)] = parsedUser.groups()[0]
@@ -386,7 +393,7 @@ class Users:
                     user = None
                     privileges = set()
 
-                    for count in xrange(0, len(value)):
+                    for count in xrange(0, len(value or [])):
                         # The first column is always the username
                         if count == 0:
                             user = value[count]
@@ -417,12 +424,13 @@ class Users:
 
                             # In Firebird we get one letter for each privilege
                             elif Backend.isDbms(DBMS.FIREBIRD):
-                                privileges.add(FIREBIRD_PRIVS[privilege.strip()])
+                                if privilege.strip() in FIREBIRD_PRIVS:
+                                    privileges.add(FIREBIRD_PRIVS[privilege.strip()])
 
                             # In DB2 we get Y or G if the privilege is
                             # True, N otherwise
                             elif Backend.isDbms(DBMS.DB2):
-                                privs = privilege.split(",")
+                                privs = privilege.split(',')
                                 privilege = privs[0]
                                 if len(privs) > 1:
                                     privs = privs[1]
@@ -455,7 +463,7 @@ class Users:
 
                 if Backend.isDbms(DBMS.MYSQL):
                     for user in users:
-                        parsedUser = re.search("[\047]*(.*?)[\047]*\@", user)
+                        parsedUser = re.search(r"['\"]?(.*?)['\"]?\@", user)
 
                         if parsedUser:
                             users[users.index(user)] = parsedUser.groups()[0]
@@ -470,32 +478,35 @@ class Users:
                 if Backend.isDbms(DBMS.MYSQL) and kb.data.has_information_schema:
                     user = "%%%s%%" % user
 
-                infoMsg = "fetching number of privileges "
-                infoMsg += "for user '%s'" % outuser
-                logger.info(infoMsg)
-
-                if Backend.isDbms(DBMS.MYSQL) and not kb.data.has_information_schema:
-                    query = rootQuery.blind.count2 % user
-                elif Backend.isDbms(DBMS.MYSQL) and kb.data.has_information_schema:
-                    query = rootQuery.blind.count % (conditionChar, user)
-                elif Backend.isDbms(DBMS.ORACLE) and query2:
-                    query = rootQuery.blind.count2 % user
+                if Backend.isDbms(DBMS.INFORMIX):
+                    count = 1
                 else:
-                    query = rootQuery.blind.count % user
+                    infoMsg = "fetching number of privileges "
+                    infoMsg += "for user '%s'" % outuser
+                    logger.info(infoMsg)
 
-                count = inject.getValue(query, union=False, error=False, expected=EXPECTED.INT, charsetType=CHARSET_TYPE.DIGITS)
+                    if Backend.isDbms(DBMS.MYSQL) and not kb.data.has_information_schema:
+                        query = rootQuery.blind.count2 % user
+                    elif Backend.isDbms(DBMS.MYSQL) and kb.data.has_information_schema:
+                        query = rootQuery.blind.count % (conditionChar, user)
+                    elif Backend.isDbms(DBMS.ORACLE) and query2:
+                        query = rootQuery.blind.count2 % user
+                    else:
+                        query = rootQuery.blind.count % user
 
-                if not isNumPosStrValue(count):
-                    if not retrievedUsers and Backend.isDbms(DBMS.ORACLE) and not query2:
-                        infoMsg = "trying with table USER_SYS_PRIVS"
-                        logger.info(infoMsg)
+                    count = inject.getValue(query, union=False, error=False, expected=EXPECTED.INT, charsetType=CHARSET_TYPE.DIGITS)
 
-                        return self.getPrivileges(query2=True)
+                    if not isNumPosStrValue(count):
+                        if not retrievedUsers and Backend.isDbms(DBMS.ORACLE) and not query2:
+                            infoMsg = "trying with table USER_SYS_PRIVS"
+                            logger.info(infoMsg)
 
-                    warnMsg = "unable to retrieve the number of "
-                    warnMsg += "privileges for user '%s'" % outuser
-                    logger.warn(warnMsg)
-                    continue
+                            return self.getPrivileges(query2=True)
+
+                        warnMsg = "unable to retrieve the number of "
+                        warnMsg += "privileges for user '%s'" % outuser
+                        logger.warn(warnMsg)
+                        continue
 
                 infoMsg = "fetching privileges for user '%s'" % outuser
                 logger.info(infoMsg)
@@ -514,6 +525,8 @@ class Users:
                         query = rootQuery.blind.query2 % (user, index)
                     elif Backend.isDbms(DBMS.FIREBIRD):
                         query = rootQuery.blind.query % (index, user)
+                    elif Backend.isDbms(DBMS.INFORMIX):
+                        query = rootQuery.blind.query % (user,)
                     else:
                         query = rootQuery.blind.query % (user, index)
 
@@ -525,8 +538,8 @@ class Users:
                     # In PostgreSQL we get 1 if the privilege is True,
                     # 0 otherwise
                     if Backend.isDbms(DBMS.PGSQL) and ", " in privilege:
-                        privilege = privilege.replace(", ", ",")
-                        privs = privilege.split(",")
+                        privilege = privilege.replace(", ", ',')
+                        privs = privilege.split(',')
                         i = 1
 
                         for priv in privs:
@@ -545,12 +558,12 @@ class Users:
                     # In MySQL < 5.0 we get Y if the privilege is
                     # True, N otherwise
                     elif Backend.isDbms(DBMS.MYSQL) and not kb.data.has_information_schema:
-                        privilege = privilege.replace(", ", ",")
-                        privs = privilege.split(",")
+                        privilege = privilege.replace(", ", ',')
+                        privs = privilege.split(',')
                         i = 1
 
                         for priv in privs:
-                            if priv.upper() == "Y":
+                            if priv.upper() == 'Y':
                                 for position, mysqlPriv in MYSQL_PRIVS.items():
                                     if position == i:
                                         privileges.add(mysqlPriv)
@@ -561,17 +574,21 @@ class Users:
                     elif Backend.isDbms(DBMS.FIREBIRD):
                         privileges.add(FIREBIRD_PRIVS[privilege.strip()])
 
+                    # In Informix we get one letter for the highest privilege
+                    elif Backend.isDbms(DBMS.INFORMIX):
+                        privileges.add(INFORMIX_PRIVS[privilege.strip()])
+
                     # In DB2 we get Y or G if the privilege is
                     # True, N otherwise
                     elif Backend.isDbms(DBMS.DB2):
-                        privs = privilege.split(",")
+                        privs = privilege.split(',')
                         privilege = privs[0]
                         privs = privs[1]
                         privs = list(privs.strip())
                         i = 1
 
                         for priv in privs:
-                            if priv.upper() in ("Y", "G"):
+                            if priv.upper() in ('Y', 'G'):
                                 for position, db2Priv in DB2_PRIVS.items():
                                     if position == i:
                                         privilege += ", " + db2Priv
