@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 
 """
-Copyright (c) 2006-2017 sqlmap developers (http://sqlmap.org/)
-See the file 'doc/COPYING' for copying permission
+Copyright (c) 2006-2018 sqlmap developers (http://sqlmap.org/)
+See the file 'LICENSE' for copying permission
 """
 
 import base64
@@ -10,7 +10,7 @@ import base64
 from lib.core.enums import PRIORITY
 from lib.core.settings import UNICODE_ENCODING
 
-__priority__ = PRIORITY.LOWEST
+__priority__ = PRIORITY.LOW
 
 def dependencies():
     pass
